%define version cvs
Summary:	A highly-available distributed filesystem
Name:		intermezzo
Version:	%{version}
Release:	1
Source:		ftp://ftp.inter-mezzo.org/pub/intermezzo/intermezzo-%{version}.tgz
Copyright:	GPL
BuildRoot:      /var/tmp/%{name}-broot
Group:		Networking/Daemons
URL:		http://www.inter-mezzo.org/
Requires:	perl-Time-HiRes perl-Storable perl-POE perl-Term-ReadLine-Gnu
# The following are needed for the build, at least.
Requires:	perl-XML-Simple perl-XML-Parser
# This is a funky way to to BuildRequires, but it makes cross-building
# SRPMS a little easier.
%(rpm -q rpm >/dev/null 2>&1 && echo 'BuildRequires: %{requires}')
# Finally, we require the kernel-source package to build Presto.
Requires:	kernel-source
Requires:	mount >= 2.10m-6.1
Requires:	e2fsprogs >= 1.22
Packager:	William Stearns <wstearns@pobox.com>, Brian J. Murrell <brian@mountainviewdata.com>, and Gordon Matzigkeit <gord@fig.org>
Vendor:		Stelias Computing, Carnegie Mellon University, Red Hat and others.


%description
InterMezzo is a distributed filesystem inspired by Coda, but much simpler.


%prep
%setup -n intermezzo-%{version}


%build
make all PRESTO=


%install
if [ "$RPM_BUILD_ROOT" = "/var/tmp/intermezzo-broot" ]; then
	rm -rf $RPM_BUILD_ROOT

	install -d $RPM_BUILD_ROOT/etc/sysconfig
	#I believe the fhs requires init scripts in /etc/init.d as opposed to /etc/rc.d/init.d
	install -d $RPM_BUILD_ROOT/etc/init.d
	install -d $RPM_BUILD_ROOT/usr/lib
	install -d $RPM_BUILD_ROOT/usr/share/man/man1
	install -d $RPM_BUILD_ROOT/usr/share/man/man3
	install -d $RPM_BUILD_ROOT/usr/share/doc
	install -d $RPM_BUILD_ROOT/usr/sbin
	install -d $RPM_BUILD_ROOT/usr/src
	install -d $RPM_BUILD_ROOT/usr/src/presto-%{version}
	install -d $RPM_BUILD_ROOT/usr/src/presto-%{version}/linux
	install -d $RPM_BUILD_ROOT/usr/src/presto-%{version}/patches
	install -d $RPM_BUILD_ROOT/usr/src/presto-%{version}/tests

	make install PRESTO= DOC= DESTDIR=$RPM_BUILD_ROOT

	# Install the Presto sources.
	SRCPRESTO=$RPM_BUILD_ROOT/usr/src/presto-%{version}
	mkdir -p $SRCPRESTO
	(cd presto && tar -cf - .) | (cd $SRCPRESTO && tar -xvBpf -)

	# Install the test harness and strip build code.
	tar -cf - tests | (cd $RPM_BUILD_ROOT/usr/lib/intermezzo && tar -xvBpf -)
	lento/tools/use-lib $RPM_BUILD_ROOT/usr/lib/intermezzo/tests/common.sh
else
	echo Invalid Build root \'"$RPM_BUILD_ROOT"\'
	exit 1
fi

%clean
if [ "$RPM_BUILD_ROOT" = "/var/tmp/intermezzo-broot" ]; then
	rm -rf $RPM_BUILD_ROOT
else
	echo Invalid Build root \'"$RPM_BUILD_ROOT"\'
	exit 1
fi


%pre
#Does this _really_ need to force the gid?  I have worries about an app that requires a particular gid.
if ! grep "^InterMezzo:" /etc/group &> /dev/null; then
    gid=4711			# start with the default
    while [ $gid -lt 65536 ]; do
	groupadd -g $gid InterMezzo &> /dev/null
	if [ $? = 0 ]; then	# success!
	    gid=65567		# exit the loop
	fi
    done
fi



%post
chkconfig --add lento

# FIXME: We may eventually support and presto RPMs for stock kernels.
# Even if we do, we leave this option open for people with custom
# kernels.
cat <<EOF
Please build and install the Presto kernel module before running
InterMezzo:

  # cd /usr/src/presto-%{version}
  # make install
  # /etc/init.d/presto start

For more information, see the InterMezzo HOWTO,
/usr/share/doc/%{package}-%{version}/InterMezzo-HOWTO.html
EOF


%preun
cd /usr/src/presto-%{version}
make distclean >/dev/null
test -L linux/version.h && rm linux/version.h
test -d .depfiles && rmdir .depfiles
if [ "$1" -eq 0 ]; then
        chkconfig --del lento || exit 0
fi


%postun
if [ "$1" -eq 0 ]; then
	groupdel InterMezzo
fi


%files
%defattr(-, root, root)
			%doc	COPYING
			%doc	ChangeLog
			%doc	INSTALL
			%doc	Makefile
			%doc	NEWS
			%doc	doc
			%doc	doc/InterMezzo-HOWTO.html
			%doc	doc/InterMezzo-HOWTO.sgml
			%doc	doc/InterMezzo-ext3.txt
			%doc	doc/KML-Expect.html
			%doc	doc/Makefile
			%doc	doc/VERSIONING
			%doc	doc/fsetdb.sgml
			%doc	doc/intermezzo.5
			%doc	doc/intermezzo.sgml
			%doc	doc/internals.html
			%doc	doc/internals.pod
			%doc	doc/kernelapi.html
			%doc	doc/kernelapi.pod
			%doc	doc/kernelapi.sgml
			%doc	doc/message.sgml
			%doc	doc/mkizofs.sgml
			%doc	doc/protocol.txt
			%doc	doc/semantics.html
			%doc	doc/semantics.pod
			%doc	doc/semantics.txt
			%doc	doc/serverdb.sgml
			%doc	doc/sysid.sgml
%attr(644,root,root)	%config	/etc/sysconfig/intermezzo
%attr(755,root,root)		/etc/init.d/lento
#Is this actually used?  It doesn't seem to be installed to the buildroot.
#%attr(755,root,root)		 /etc/init.d/presto
%attr(755,root,root)	%dir	/usr/lib/intermezzo
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento
%attr(444,root,root)		/usr/lib/intermezzo/Lento/ACT.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Acceptor.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Bootstrap.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento/Bulk
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Bulk/Desc.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Bulk/README
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Bulk/Sink.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Bulk/Source.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/CacheTable.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Callback.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Client.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/ClientDB.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Connection.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Connector.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/CreateML.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Debuggable.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/EventSupport.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Fileset.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento/Filter
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Filter/Packet.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Filter/Upcall.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Fsetdb.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/InControl.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento/InterMezzo
%attr(444,root,root)		/usr/lib/intermezzo/Lento/InterMezzo/ReqHandler.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/InterMezzo/UpcallHandler.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento/KML
%attr(444,root,root)		/usr/lib/intermezzo/Lento/KML.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/KML/Rec.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/KML/Reint.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/KML/ReintFS.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/KML/ReintLento.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/LML.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento/LML
%attr(444,root,root)		/usr/lib/intermezzo/Lento/LML/Rec.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/List.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Packet.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Pinger.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Psdev.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/Lento/RPCS
%attr(444,root,root)		/usr/lib/intermezzo/Lento/RPCS/GetPermit.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Replicator.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/ReqDispatcher.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Server.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/ServerSemantics.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Serverdb.pm
%attr(444,root,root)		/usr/lib/intermezzo/Lento/Utils.pm
%attr(755,root,root)		/usr/lib/intermezzo/fsetroot
%attr(755,root,root)	%dir	/usr/lib/intermezzo/i386-linux
%attr(444,root,root)		/usr/lib/intermezzo/i386-linux/SetFS.pm
%attr(755,root,root)	%dir	/usr/lib/intermezzo/i386-linux/auto
%attr(755,root,root)	%dir	/usr/lib/intermezzo/i386-linux/auto/Lento
%attr(644,root,root)		/usr/lib/intermezzo/i386-linux/auto/Lento/.packlist
%attr(755,root,root)	%dir	/usr/lib/intermezzo/i386-linux/auto/SetFS
%attr(644,root,root)		/usr/lib/intermezzo/i386-linux/auto/SetFS/.packlist
%attr(444,root,root)		/usr/lib/intermezzo/i386-linux/auto/SetFS/SetFS.bs
%attr(555,root,root)		/usr/lib/intermezzo/i386-linux/auto/SetFS/SetFS.so
%attr(444,root,root)		/usr/lib/intermezzo/i386-linux/auto/SetFS/autosplit.ix
%attr(644,root,root)		/usr/lib/intermezzo/i386-linux/perllocal.pod
%attr(555,root,root)		/usr/sbin/closejournal
%attr(555,root,root)		/usr/sbin/inconfig
%attr(755,root,root)		/usr/sbin/inconfig-check
%attr(555,root,root)		/usr/sbin/kml-print
%attr(555,root,root)		/usr/sbin/lento
%attr(755,root,root)		/usr/sbin/mkizofs
%attr(555,root,root)		/usr/sbin/umountizo
%attr(444,root,root)		/usr/share/man/man1/closejournal.1.gz
%attr(444,root,root)		/usr/share/man/man1/kml-print.1.gz
%attr(444,root,root)		/usr/share/man/man1/lento.1.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::ACT.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Acceptor.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Bootstrap.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Bulk::Source.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Connection.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Connector.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Fileset.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::KML.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::KML::Reint.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::KML::ReintFS.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::KML::ReintLento.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::LML.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::List.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Pinger.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::ReqDispatcher.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/Lento::Server.3pm.gz
%attr(444,root,root)		/usr/share/man/man3/SetFS.3pm.gz
%attr(755,root,root)	%dir	/usr/src/presto-%{version}
%attr(644,root,root)		/usr/src/presto-%{version}/COPYING
%attr(644,root,root)		/usr/src/presto-%{version}/MANIFEST
%attr(644,root,root)		/usr/src/presto-%{version}/Makefile.in
%attr(644,root,root)		/usr/src/presto-%{version}/README
%attr(644,root,root)		/usr/src/presto-%{version}/cache.c
%attr(755,root,root)		/usr/src/presto-%{version}/configure
%attr(644,root,root)		/usr/src/presto-%{version}/configure.in
%attr(644,root,root)		/usr/src/presto-%{version}/dcache.c
%attr(644,root,root)		/usr/src/presto-%{version}/dir.c
%attr(644,root,root)		/usr/src/presto-%{version}/file.c
%attr(644,root,root)		/usr/src/presto-%{version}/inode.c
%attr(644,root,root)		/usr/src/presto-%{version}/intermezzo.c
%attr(644,root,root)		/usr/src/presto-%{version}/journal.c
%attr(644,root,root)		/usr/src/presto-%{version}/journal_ext2.c
%attr(644,root,root)		/usr/src/presto-%{version}/journal_ext3.c
%attr(644,root,root)		/usr/src/presto-%{version}/kmlreint.c
%attr(755,root,root)	%dir	/usr/src/presto-%{version}/linux
%attr(644,root,root)		/usr/src/presto-%{version}/linux/Makefile
%attr(644,root,root)		/usr/src/presto-%{version}/linux/filter.h
%attr(644,root,root)		/usr/src/presto-%{version}/linux/intermezzo_fs.h
%attr(644,root,root)		/usr/src/presto-%{version}/linux/intermezzo_kml.h
%attr(644,root,root)		/usr/src/presto-%{version}/linux/intermezzo_psdev.h
%attr(644,root,root)		/usr/src/presto-%{version}/linux/intermezzo_upcall.h
%attr(644,root,root)		/usr/src/presto-%{version}/methods.c
%attr(755,root,root)	%dir	/usr/src/presto-%{version}/patches
%attr(644,root,root)		/usr/src/presto-%{version}/patches/README
%attr(644,root,root)		/usr/src/presto-%{version}/patches/loop_discard.diff
%attr(644,root,root)		/usr/src/presto-%{version}/psdev.c
%attr(644,root,root)		/usr/src/presto-%{version}/redo
%attr(644,root,root)		/usr/src/presto-%{version}/super.c
%attr(644,root,root)		/usr/src/presto-%{version}/sysctl.c
%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests
%attr(644,root,root)		/usr/src/presto-%{version}/tests/loop_discard.c
%attr(644,root,root)		/usr/src/presto-%{version}/tests/test_open.c
%attr(644,root,root)		/usr/src/presto-%{version}/tests/time_create.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/ChangeLog
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/MANIFEST
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/Makefile
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/README
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/common.sh
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/config.mk
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/cron_test.pl
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/defaults.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/fs_halt.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/fs_setup.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/fscomp.pl
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/halt_test.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/iface_halt.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/iface_setup.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_test.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/lento_halt.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/lento_setup.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/lento_wait.pl
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/log_halt.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/log_setup.sh
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/make.rules
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/make_tar.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/run_test.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/voldb_setup.sh
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_scripts
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_scripts/advanced
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/advanced/identity.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/advanced/open.pl
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/advanced/security.sh
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_scripts/basic
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_create.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_group.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_groups.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_link.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_mkdir.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_mknod.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_owner.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_rename.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_setattr.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_symlink.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/basic/kml_unlink.sh
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_scripts/bugs
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/cvs_attr.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/cvs_rename.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/cvs_time.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/mmap-2.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/rsync.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/symlink.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/bugs/unlink.sh
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_scripts/cvs
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/cvs
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/cvs
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/cvs_init
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/cvs_client
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/cvs_server
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/cvspserver
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/cvs/sshd
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_scripts/sendmail
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/sendmail/intermezzo.cf
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/sendmail/sendmail.sh
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/sendmail/setup
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_scripts/sendmail/test
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/kml_utils
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/Makefile
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/cvs_attr.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/cvs_rename.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/cvs_time.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/hello.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/mmap-2.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/mmap.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/open.c
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/kml_utils/symlink.c
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/basic
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/basic/test_run
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/test_configs/Makefile
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/complex
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/complex/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/complex/test_clean
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/complex/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/complex/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/complex/test_setup
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/fail_alarm
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm/test_clean
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm/test_setup
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/fail_alarm_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm_check/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm_check/test_clean
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm_check/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm_check/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_alarm_check/test_setup
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/fail_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_check/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_check/test_clean
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_check/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_check/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_check/test_setup
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/fail_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_run/test_clean
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_run/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_run/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fail_run/test_setup
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/fsonly
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/test_configs/fsonly/Makefile
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fsonly/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fsonly/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/fsonly/test_setup
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_configs/play
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/play/loop-run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/play/strace-test
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/play/test-mc
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/play/test-rm
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/play/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_configs/play/test_run
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_regr
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_regr/simple
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/sim_dirsuit.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/sim_filesuit.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/test_run
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_append.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_echo.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_hardlinkdir.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_mkdir.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_renamedir.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_renamefile.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_rmdir.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_symlink.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_symlinkdir.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_touch.sh
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_regr/simple/tst_unlink.sh
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/test_regr/Makefile
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple/copy_to_all
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/copy_to_all/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/copy_to_all/test_run
#%attr(644,root,root)		/usr/src/presto-%{version}/tests/test_simple/Makefile
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple/copy_to_client
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/copy_to_client/test_run
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple/large_copy
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/large_copy/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/large_copy/test_run
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple/lento_restart
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/lento_restart/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/lento_restart/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/lento_restart/test_run
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple/links
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/links/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/links/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/links/test_run
#%attr(755,root,root)	%dir	/usr/src/presto-%{version}/tests/test_simple/many_copy
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/many_copy/test_check
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/many_copy/test_env
#%attr(755,root,root)		/usr/src/presto-%{version}/tests/test_simple/many_copy/test_run
%attr(644,root,root)		/usr/src/presto-%{version}/upcall.c
%attr(644,root,root)		/usr/src/presto-%{version}/vfs.c


%changelog
* Mon Aug 06 2001 William Stearns <wstearns@pobox.com>
- Test build from cvs/izopkg
- recheck file list

* Thu Jul 26 2001 William Stearns <wstearns@pobox.com>
- Updated tar to version 1.0.0.0.
- Explicit file list
- suck in intermezzo.spec.in changes
- Do not include *~, .cvsignore, or CVS/* files in final rpm.
- Other minor spec updates.

* Tue Apr 24 2001 Gordon Matzigkeit <gord@fig.org>
- Actually install manpages.

* Wed Apr 11 2001 Brian J. Murrell <brian@mountainviewdata.com>
- include manpages

* Mon Apr 09 2001 Brian J. Murrell <brian@mountainviewdata.com>
- numerous changes to prepare for 1.0 release

* Mon Nov 27 2000 Gordon Matzigkeit <gord@fig.org>
- Initial spec


